@@ -621,7 +621,8 @@ impl Module {
     }
   }
 
-  fn new_from_type_imports(
+  /// Create a synthetic module from a vector of type imports
+  pub fn new_from_type_imports(
     specifier: ModuleSpecifier,
     type_imports: Vec<String>,
     maybe_resolver: Option<&dyn Resolver>,
@@ -1575,7 +1576,10 @@ impl<'a> Builder<'a> {
     // Enrich with cache info from the loader
     for slot in self.graph.module_slots.values_mut() {
       if let ModuleSlot::Module(ref mut module) = slot {
-        module.maybe_cache_info = self.loader.get_cache_info(&module.specifier);
+        if !matches!(module.kind, ModuleKind::Synthetic) {
+          module.maybe_cache_info =
+            self.loader.get_cache_info(&module.specifier);
+        }
       }
     }
     // Enrich with checksums from locker
